@@ -1,6 +1,6 @@
 use bevy::ecs::{entity::Entity, system::Command};
 
-use crate::{FocusState, Focusable, Focused};
+use crate::{FocusState, Focused};
 
 pub(crate) fn set_focus_state(entity: Entity, new_state: FocusState) -> UpdateFocusable {
     UpdateFocusable { entity, new_state }
@@ -12,10 +12,7 @@ pub(crate) struct UpdateFocusable {
 impl Command for UpdateFocusable {
     fn write(self, world: &mut bevy::prelude::World) {
         let mut entity = world.entity_mut(self.entity);
-        if let Some(mut entity) = entity.get_mut::<Focusable>() {
-            entity.focus_state = self.new_state;
-        }
-        if let FocusState::Focused = self.new_state {
+        if matches!(self.new_state, FocusState::Focused) {
             entity.insert(Focused);
         } else {
             entity.remove::<Focused>();
